
:autogenerated:

newtonprop package
==================

.. automodule:: newtonprop
    


    Submodules:

    .. toctree::
       :maxdepth: 1

       newtonprop.propagator



    Summary
    -------

    ``__all__`` Functions:


    .. list-table::
    
       * - :func:`newton <newtonprop.propagator.step>`
         - Evaluate $f(A\,dt)\,v$, for example $e^{-i\,A\,dt}\,v$ for the propagation of a quantum state.
    


